"""

Stock News
----------

Downloads stock ticker news from yahoo such as from https://ca.finance.yahoo.com/quote/IP.CN/
 

IIROC - Investment Industry Regulatory Organization of Canada (IIROC) contains 
information about stock halts

https://www.iiroc.ca/Pages/default.aspx
"""

from cad_tickers.news.iiroc_halts import *
from cad_tickers.news.stock_news import *